import { getPost } from "@/backend/post";
import DOMPurify from "dompurify";
import { JSDOM } from "jsdom";
import { nunito_sans, raleway } from "@/app/fonts";
import parse, {
  domToReact,
  Element,
  HTMLReactParserOptions,
} from "html-react-parser";
import { DummyPostSlug, DummyPostString } from "@/components/dummyPost";

const options: HTMLReactParserOptions = {
  replace: (domNode) => {
    if (domNode instanceof Element && domNode.attribs) {
      // console.log(domNode.attribs)
      if (domNode.name === "h1") {
        if (domNode.attribs.class === "title") {
          return (
            <h1 className={`${raleway.className} mx-auto w-224 text-4xl`}>
              {domToReact(domNode.children)}
            </h1>
          );
        } else {
          return (
              <h1 className={`${raleway.className} mx-auto w-224 text-3xl`}>
                  {domToReact(domNode.children)}
              </h1>
          );
        }
      } else if (domNode.name === "h2") {
        return (
            <h1 className={`${raleway.className} mx-auto w-224 text-2xl`}>
                {domToReact(domNode.children)}
            </h1>
        );
      } else if (domNode.name === "h3") {
        return (
            <h1 className={`${raleway.className} mx-auto w-224 text-xl`}>
                {domToReact(domNode.children)}
            </h1>
        );
      } else if (domNode.name === "p") {
        if (domNode.attribs.class === "paragraph") {
          return (
              <h1 className={`${nunito_sans.className} mx-auto w-224`}>
                  {domToReact(domNode.children)}
              </h1>
          );
        } else {
          const classes = domNode.attribs.class.split(" ");
          if (classes.includes("code")) {
              if (classes.includes("shell")) {

              } else if (classes.includes("go") || classes.includes("golang")) {

              } else {

              }
          }
        }
      }
    }
  },
};

export default async function Post({ params }: { params: { slug: string } }) {
  let content = "";

  const dummySlug = await DummyPostSlug();
  if (dummySlug === params.slug) {
    content = await DummyPostString();
    console.log(content);
  } else {
    content = await getPost(params.slug);
  }

  content = DOMPurify(new JSDOM("<!DOCTYPE html>").window).sanitize(content);
  // console.log(content)
  const elem = parse(content, options);

  return <div className={`flex flex-col`}>{elem}</div>;
}
